﻿using System;
using System.Globalization;
using System.Windows.Data;
using System.Windows.Media;

namespace GermanyRuTest.Common
{
    /// <summary>
    ///     Class ButtonStateToBackgroundColorConverter.
    ///     convert EButtonState to button color
    ///     Change button colors Here!
    /// </summary>
    /// <seealso cref="System.Windows.Data.IValueConverter" />
    public class ButtonStateToBackgroundColorConverter : IValueConverter
    {
        private static Brush _buttonBrushNormal;

        private static Brush _buttonBrushPressed;

        /// <summary>
        ///     Initializes a new instance of the <see cref="ButtonStateToBackgroundColorConverter" /> class.
        /// </summary>
        public ButtonStateToBackgroundColorConverter()
        {
            _buttonBrushNormal = new SolidColorBrush(Color.FromArgb(0xFF, 0x9F, 0x10, 0x14));
            _buttonBrushPressed = new SolidColorBrush(Color.FromArgb(0xFF, 0xF0, 0x90, 0x94));
        }

        /// <summary>
        ///     Converts a value.
        /// </summary>
        /// <param name="value">The value produced by the binding source.</param>
        /// <param name="targetType">The type of the binding target property.</param>
        /// <param name="parameter">The converter parameter to use.</param>
        /// <param name="culture">The culture to use in the converter.</param>
        /// <returns>A converted value. If the method returns null, the valid null value is used.</returns>
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            EButtonState val = (EButtonState)value;
            if (val == EButtonState.Pressed)
            {
                return _buttonBrushPressed;
            }
            return _buttonBrushNormal;
        }

        /// <summary>
        ///     Converts a value back. Not supported
        /// </summary>
        /// <param name="value">The value that is produced by the binding target.</param>
        /// <param name="targetType">The type to convert to.</param>
        /// <param name="parameter">The converter parameter to use.</param>
        /// <param name="culture">The culture to use in the converter.</param>
        /// <returns>A converted value. If the method returns null, the valid null value is used.</returns>
        /// <exception cref="NotSupportedException"></exception>
        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            throw new NotSupportedException();
        }
    }
}