﻿using System;
using System.Globalization;
using System.Windows.Data;

namespace GermanyRuTest.Common
{
    /// <summary>
    ///     Class ItemVisibilityConverter.
    ///     Convert enum EVisibility to the visibility text
    /// </summary>
    /// <seealso cref="System.Windows.Data.IValueConverter" />
    public class ItemVisibilityConverter : IValueConverter
    {
        /// <summary>
        ///     Converts a value.
        /// </summary>
        /// <param name="value">The value produced by the binding source.</param>
        /// <param name="targetType">The type of the binding target property.</param>
        /// <param name="parameter">The converter parameter to use.</param>
        /// <param name="culture">The culture to use in the converter.</param>
        /// <returns>A converted value. If the method returns null, the valid null value is used.</returns>
        /// <exception cref="ArgumentOutOfRangeException"></exception>
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            EVisibility val = (EVisibility)value;
            string ret;
            switch (val)
            {
                case EVisibility.Hidden:
                    ret = "Hidden";
                    break;
                case EVisibility.Visible:
                    ret = "Visible";
                    break;
                case EVisibility.Collapsed:
                    ret = "Collapsed";
                    break;
                default:
                    throw new ArgumentOutOfRangeException();
            }
            return ret;
        }

        /// <summary>
        ///     Converts a value back. Not supported
        /// </summary>
        /// <param name="value">The value that is produced by the binding target.</param>
        /// <param name="targetType">The type to convert to.</param>
        /// <param name="parameter">The converter parameter to use.</param>
        /// <param name="culture">The culture to use in the converter.</param>
        /// <returns>A converted value. If the method returns null, the valid null value is used.</returns>
        /// <exception cref="NotSupportedException"></exception>
        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            throw new NotSupportedException();
        }
    }
}