﻿using GermanyRuTest.Common;

namespace GermanyRuTest.Model
{
    /// <summary>
    ///     Class ButtonData.
    ///     Encapsulate button data: Id and state
    /// </summary>
    /// <seealso cref="GermanyRuTest.Common.NotifyPropertyChanged" />
    internal class ButtonData : NotifyPropertyChanged
    {
        private readonly int _id;

        private EButtonState _buttonState;

        /// <summary>
        ///     Initializes a new instance of the <see cref="ButtonData" /> class.
        /// </summary>
        /// <param name="id">The identifier.</param>
        /// <param name="buttonState">State of the button.</param>
        public ButtonData(int id, EButtonState buttonState)
        {
            _id = id;
            _buttonState = buttonState;
        }

        /// <summary>
        ///     Gets or sets the state of the button.
        /// </summary>
        /// <value>The state of the button.</value>
        public EButtonState ButtonState
        {
            get
            {
                return _buttonState;
            }
            set
            {
                _buttonState = value;
                OnPropertyChanged(nameof(ButtonState));
            }
        }

        /// <summary>
        ///     Gets the button identifier.
        /// </summary>
        /// <value>The identifier.</value>
        public int Id
        {
            get
            {
                return _id;
            }
        }
    }
}