﻿using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Collections.Specialized;
using System.ComponentModel;

using GermanyRuTest.Common;

namespace GermanyRuTest.Model
{
    /// <summary>
    ///     Class ButtonDataCollection. This class cannot be inherited.
    ///     Manage summary buttons calculated value.
    ///     As every button represent a bit state ans Id represent the bit position
    /// </summary>
    /// <seealso cref="System.Collections.ObjectModel.ObservableCollection{GermanyRuTest.Model.ButtonData}" />
    internal sealed class ButtonDataCollection : ObservableCollection<ButtonData>
    {
        public event PropertyChangedEventHandler ValueChanged;

        private readonly Dictionary<int, ButtonData> _posMap = new Dictionary<int, ButtonData>();

        private int _summaryValue;

        /// <summary>
        ///     Initializes a new instance of the <see cref="ButtonDataCollection" /> class.
        /// </summary>
        public ButtonDataCollection()
        {
            CollectionChanged += ButtonDataCollectionCollectionChanged;
        }

        private void ButtonDataCollectionCollectionChanged(object sender, NotifyCollectionChangedEventArgs e)
        {
            if (e.Action == NotifyCollectionChangedAction.Add)
            {
                ButtonData buttonData = (ButtonData)e.NewItems[0];
                int key = buttonData.Id;
                if (!_posMap.ContainsKey(key))
                {
                    _posMap.Add(key, buttonData);
                    buttonData.PropertyChanged += ButtonDataPropertyChanged;
                }
            }
            else if (e.Action == NotifyCollectionChangedAction.Remove)
            {
                ButtonData buttonData = (ButtonData)e.NewItems[0];
                int key = buttonData.Id;
                _posMap.Remove(key);
            }
            else if (e.Action == NotifyCollectionChangedAction.Reset)
            {
                _posMap.Clear();
            }
        }

        private void ButtonDataPropertyChanged(object sender, PropertyChangedEventArgs e)
        {
            string propertyName = e.PropertyName;
            if (propertyName == "ButtonState")
            {
                ButtonData buttonData = sender as ButtonData;
                if (buttonData != null)
                {
                    int pos = buttonData.Id;
                    int bit = 1 << pos;
                    if (buttonData.ButtonState == EButtonState.Normal)
                    {
                        SummaryValue &= ~bit;
                    }
                    else
                    {
                        SummaryValue |= bit;
                    }
                }
            }
        }

        private void OnValueChanged(PropertyChangedEventArgs e)
        {
            ValueChanged?.Invoke(this, e);
        }

        /// <summary>
        ///     Gets the summary value of buttons state
        /// </summary>
        /// <value>The summary value.</value>
        public int SummaryValue
        {
            get
            {
                return _summaryValue;
            }
            private set
            {
                _summaryValue = value;
                OnValueChanged(new PropertyChangedEventArgs(nameof(SummaryValue)));
            }
        }
    }
}