﻿using System;

using GermanyRuTest.Common;
using GermanyRuTest.Model;

namespace GermanyRuTest.ViewModel
{
    /// <summary>
    ///     Class ButtonsUserControlVm.
    ///     ViewModel for ButtonsUserControl
    /// </summary>
    /// <seealso cref="GermanyRuTest.Common.ViewModelBase" />
    /// <seealso cref="ButtonUserControl" />
    internal class ButtonUserControlVm : ViewModelBase
    {
        private readonly ButtonData _buttonData;

        private string _buttonText;

        /// <summary>
        ///     Initializes a new instance of the <see cref="ButtonUserControlVm" /> class.
        /// </summary>
        /// <param name="buttonData">The button data.</param>
        /// <exception cref="ArgumentNullException">buttonData</exception>
        public ButtonUserControlVm(ButtonData buttonData)
        {
            if (buttonData == null)
            {
                throw new ArgumentNullException(nameof(buttonData));
            }
            _buttonData = buttonData;
            if (_buttonData != null)
            {
                ButtonText = _buttonData.Id.ToString();
            }
        }

        /// <summary>
        ///     Press the Button
        /// </summary>
        public void ButtonPressed()
        {
            ButtonState = ButtonState == EButtonState.Normal ? EButtonState.Pressed : EButtonState.Normal;
        }

        /// <summary>
        ///     Gets or sets the state of the button.
        /// </summary>
        /// <value>The state of the button.</value>
        public EButtonState ButtonState
        {
            get
            {
                return _buttonData.ButtonState;
            }
            set
            {
                _buttonData.ButtonState = value;

                OnPropertyChanged(nameof(ButtonState));
                //OnPropertyChanged("Background");
            }
        }

        /// <summary>
        ///     Gets or sets the button text.
        /// </summary>
        /// <value>The button text.</value>
        public string ButtonText
        {
            get
            {
                return _buttonText;
            }
            set
            {
                _buttonText = value;
                OnPropertyChanged(nameof(ButtonText));
            }
        }
    }
}